import{g as te,I as C,a as ae}from"../chunks/Dnm-XY8D.mjs";import"../chunks/E-vkuI0X.mjs";import{i as G}from"../chunks/BY-InYMh.mjs";import{p as J,d as K,s as T,i,u as a,g as c,f as se,n as y,t as P,b as g,c as m,a0 as _,h as W,r as z,ao as I,m as F,j as re}from"../chunks/CNnnUJHC.mjs";import{p as A}from"../chunks/CDiwszz9.mjs";import{s as $}from"../chunks/DhVU3Ruq.mjs";import{v as oe,w as le,x as ie,y as pe,z as ne,A as ue,B as de,C as ce,D as ge,E as me,F as $e,G as fe,H as he,I as H,J as ve,K as q}from"../chunks/DsH_B9zr.mjs";import{H as u,a as ke}from"../chunks/D-xhhzqz.mjs";import{S as j,a as N,E as B}from"../chunks/DysYgOuq.mjs";import{R as ye}from"../chunks/CIfmyYqU.mjs";import{T as Pe}from"../chunks/j5el3_IK.mjs";import{I as _e}from"../chunks/CunlPwQF.mjs";const Ne=(async({params:f})=>{const l=await te({});return{path:f.path,options:l}}),Te=Object.freeze(Object.defineProperty({__proto__:null,load:Ne},Symbol.toStringTag,{value:"Module"}));function b(){return[{label:oe(),value:C.IF_NEWER},{label:le(),value:C.ALWAYS},{label:ie(),value:C.NEVER}]}var we=re("<!> <!> <details><summary> </summary> <!> <!> <!></details>",1);function Ie(f,l){J(l,!1);let p=A(l,"path",8),t=A(l,"options",12);const s={withScheduling:{title:he(),help:fe(),url:u.PackageImporting.scheduling},withDeckConfigs:{title:$e(),help:me(),url:u.PackageImporting.scheduling},mergeNotetypes:{title:ge(),help:ce(),url:u.PackageImporting.updating},updateNotes:{title:de(),help:ue(),url:u.PackageImporting.updating},updateNotetypes:{title:ne(),help:pe(),url:u.PackageImporting.updating}},L=Object.values(s);let U=F(),D=F();function h(x){c(U).show(),c(D).to(x)}G(),_e(f,{get path(){return p()},importer:{doImport:()=>ae({packagePath:p(),options:t()},{alertOnError:!1})},children:(x,be)=>{ye(x,{class:"d-block",children:(Y,xe)=>{{let Q=I(()=>(i(H),a(()=>q())));Pe(Y,{get title(){return c(Q)},children:(O,X)=>{var w=we(),v=se(w);j(v,{defaultValue:!1,get value(){return t().withScheduling},set value(e){t(t().withScheduling=e,!0)},children:(e,r)=>{N(e,{$$events:{click:()=>h(Object.keys(s).indexOf("withScheduling"))},children:(n,d)=>{y();var o=P();g(()=>$(o,a(()=>s.withScheduling.title))),m(n,o)},$$slots:{default:!0}})},$$slots:{default:!0},$$legacy:!0});var E=_(v,2);j(E,{defaultValue:!1,get value(){return t().withDeckConfigs},set value(e){t(t().withDeckConfigs=e,!0)},children:(e,r)=>{N(e,{$$events:{click:()=>h(Object.keys(s).indexOf("withDeckConfigs"))},children:(n,d)=>{y();var o=P();g(()=>$(o,a(()=>s.withDeckConfigs.title))),m(n,o)},$$slots:{default:!0}})},$$slots:{default:!0},$$legacy:!0});var R=_(E,2),S=W(R),Z=W(S,!0);z(S);var V=_(S,2);j(V,{defaultValue:!1,get value(){return t().mergeNotetypes},set value(e){t(t().mergeNotetypes=e,!0)},children:(e,r)=>{N(e,{$$events:{click:()=>h(Object.keys(s).indexOf("mergeNotetypes"))},children:(n,d)=>{y();var o=P();g(()=>$(o,a(()=>s.mergeNotetypes.title))),m(n,o)},$$slots:{default:!0}})},$$slots:{default:!0},$$legacy:!0});var M=_(V,2);{let e=I(()=>(i(b),a(b)));B(M,{defaultValue:0,get choices(){return c(e)},get value(){return t().updateNotes},set value(r){t(t().updateNotes=r,!0)},children:(r,n)=>{N(r,{$$events:{click:()=>h(Object.keys(s).indexOf("updateNotes"))},children:(d,o)=>{y();var k=P();g(()=>$(k,a(()=>s.updateNotes.title))),m(d,k)},$$slots:{default:!0}})},$$slots:{default:!0},$$legacy:!0})}var ee=_(M,2);{let e=I(()=>(i(b),a(b)));B(ee,{defaultValue:0,get choices(){return c(e)},get value(){return t().updateNotetypes},set value(r){t(t().updateNotetypes=r,!0)},children:(r,n)=>{N(r,{$$events:{click:()=>h(Object.keys(s).indexOf("updateNotetypes"))},children:(d,o)=>{y();var k=P();g(()=>$(k,a(()=>s.updateNotetypes.title))),m(d,k)},$$slots:{default:!0}})},$$slots:{default:!0},$$legacy:!0})}z(R),g(e=>$(Z,e),[()=>(i(H),a(()=>ve()))]),m(O,w)},$$slots:{default:!0,tooltip:(O,X)=>{{let w=I(()=>(i(H),a(()=>q())));ke(O,{get title(){return c(w)},get url(){return i(u),a(()=>u.PackageImporting.root)},slot:"tooltip",get helpSections(){return L},$$events:{mount:v=>{T(U,v.detail.modal),T(D,v.detail.carousel)}}})}}}})}},$$slots:{default:!0}})},$$slots:{default:!0}}),K()}function We(f,l){J(l,!1);let p=A(l,"data",8);G(),Ie(f,{get path(){return i(p()),a(()=>p().path)},get options(){return i(p()),a(()=>p().options)}}),K()}export{We as component,Te as universal};
