import{k as t,o as i,q as c,v as f}from"./CNnnUJHC.mjs";import{B as y}from"./CDiwszz9.mjs";const k=Symbol("NaN");function b(r,e,n){t&&i();var o=new y(r),s=!c();f(()=>{var a=e();a!==a&&(a=k),s&&a!==null&&typeof a=="object"&&(a={}),o.ensure(a,n)})}export{b as k};
