import"./E-vkuI0X.mjs";import{i as w}from"./BY-InYMh.mjs";import{p as C,h as s,r as a,a0 as v,b as D,c as j,d as q,$ as N,j as S,_ as A}from"./CNnnUJHC.mjs";import{s as B}from"./DhVU3Ruq.mjs";import{s as c}from"./Dnm-XY8D.mjs";import{u as E,t as F,q as f}from"./DsH_B9zr.mjs";import{p as l}from"./CDiwszz9.mjs";import{p as G}from"./CIfmyYqU.mjs";var H=S('<div><div class="position-relative"><h1 class="svelte-zuiu8u"> </h1> <div><!></div></div> <!></div>');function R(_,t){C(t,!1);const d=()=>A(G,"$pageTheme",h),[h,g]=N(),n=window.getComputedStyle(document.body).direction=="rtl";let b=l(t,"id",8,void 0),T=l(t,"class",8,""),k=l(t,"title",8);w();var e=H();let m;E(e,"",{},{"--gutter-block":"2px","--container-margin":"0"});var i=s(e),o=s(i),x=s(o,!0);a(o);var r=v(o,2);let u;var y=s(r);c(y,t,"tooltip",{}),a(r),a(i);var z=v(i,2);c(z,t,"default",{}),a(e),D(()=>{var p;F(e,"id",b()),m=f(e,1,`container ${(p=T())!=null?p:""}`,"svelte-zuiu8u",m,{light:!d().isDark,dark:d().isDark,rtl:n}),B(x,k()),u=f(r,1,"help-badge position-absolute svelte-zuiu8u",null,u,{rtl:n})}),j(_,e),q(),g()}export{R as T};
