import"./E-vkuI0X.mjs";import"./BY-InYMh.mjs";import{h as z,e as M,f as S,c as o,r as X,b as x,j}from"./CNnnUJHC.mjs";import{e as s}from"./DhVU3Ruq.mjs";import{s as k}from"./Dnm-XY8D.mjs";import{t as l,q}from"./DsH_B9zr.mjs";import{p as B}from"./89V6BR2_.mjs";import{I as C,b as f}from"./Bwnpzbiq.mjs";import{p as i}from"./CDiwszz9.mjs";var D=j("<button><!></button>");function O(m,t){let c=i(t,"id",8,void 0),d=i(t,"class",8,""),u=i(t,"tooltip",8,void 0),b=i(t,"primary",8,!1),v=i(t,"active",8,!1),h=i(t,"disabled",8,!1),_=i(t,"tabbable",8,!1),p=i(t,"iconSize",8,75),g=i(t,"widthMultiplier",8,1),w=i(t,"flipX",8,!1);var e=D();let r;var I=z(e);C(I,{get flipX(){return w()},get widthMultiplier(){return g()},get iconSize(){return p()},children:(a,N)=>{var n=M(),y=S(n);k(y,t,"default",{}),o(a,n)},$$slots:{default:!0}}),X(e),x(()=>{var a;l(e,"id",c()),r=q(e,1,`icon-button ${(a=d())!=null?a:""}`,"svelte-9egv84",r,{active:v(),primary:b()}),l(e,"title",u()),e.disabled=h(),l(e,"tabindex",_()?0:-1)}),s("click",e,function(a){f.call(this,t,a)}),s("mousedown",e,B(function(a){f.call(this,t,a)})),o(m,e)}export{O as I};
