import{c as i}from"../chunks/Dnm-XY8D.mjs";import"../chunks/E-vkuI0X.mjs";import{i as s}from"../chunks/BY-InYMh.mjs";import{p as c,d as l,i as p,u}from"../chunks/CNnnUJHC.mjs";import{p as f}from"../chunks/CDiwszz9.mjs";import{p as m}from"../chunks/Mdxnp2L8.mjs";import{C as d}from"../chunks/CFB5uY-g.mjs";import{g}from"../chunks/DJ7H8Huw.mjs";function h(o){try{return BigInt(o)}catch{return null}}const _=(async({params:o})=>{const t=h(o.cardId);return{info:t!==null?await i({cid:t}):null}}),T=Object.freeze(Object.defineProperty({__proto__:null,load:_},Symbol.toStringTag,{value:"Module"}));function j(o,t){c(t,!1);let a=f(t,"data",8);const n=m.url.searchParams.get("revlog")!=="0";globalThis.anki||(globalThis.anki={}),globalThis.anki.updateCard=async e=>{const r=`/card-info/${e}`;return g(r).catch(()=>{window.location.href=r})},s(),d(o,{get stats(){return p(a()),u(()=>a().info)},get showRevlog(){return n}}),l()}export{j as component,T as universal};
