import"./E-vkuI0X.mjs";import{i as g}from"./BY-InYMh.mjs";import{p as b,e as x,f as k,c as e,d as N,h as R,r as W,b as j,i as m,u as q,j as I}from"./CNnnUJHC.mjs";import{s as P}from"./DhVU3Ruq.mjs";import{p as n,i as U}from"./CDiwszz9.mjs";import{t as l,s as f}from"./BSf7DoGY.mjs";import{q as $}from"./DsH_B9zr.mjs";import{w as p}from"./BsocXRUK.mjs";import{R as y}from"./CIfmyYqU.mjs";var z=I("<div> </div>");function L(c,t){b(t,!1);let r=n(t,"warning",8),d=n(t,"className",8,"alert-warning");g();var o=x(),v=k(o);{var _=s=>{y(s,{children:(u,A)=>{var a=z(),h=R(a,!0);W(a),j(w=>{var i;$(a,1,`col-12 alert ${(i=d())!=null?i:""} mb-0`),P(h,w)},[()=>(m(p),m(r()),q(()=>p(r())))]),l(1,a,()=>f),l(2,a,()=>f),e(u,a)},$$slots:{default:!0}})};U(v,s=>{r()&&s(_)})}e(c,o),N()}export{L as W};
