import"../chunks/E-vkuI0X.mjs";import{i as o}from"../chunks/BY-InYMh.mjs";import{p,l as m,a as f,n as c,t as i,b as n,c as _,d as g,s as l,g as x,m as u}from"../chunks/CNnnUJHC.mjs";import{s as b}from"../chunks/DhVU3Ruq.mjs";import{p as t}from"../chunks/Mdxnp2L8.mjs";function j(a,r){p(r,!1);const e=u();m(()=>t,()=>{l(e,t.error.message)}),f(),o(),c();var s=i();n(()=>b(s,x(e))),_(a,s),g()}export{j as component};
