import"./E-vkuI0X.mjs";import{i as T}from"./BY-InYMh.mjs";import{p as B,l as f,s as r,i as b,g as s,a as j,h as k,r as q,b as x,c as D,d as M,_ as N,$ as S,m as p,j as W}from"./CNnnUJHC.mjs";import{e as A}from"./DhVU3Ruq.mjs";import{s as C}from"./Dnm-XY8D.mjs";import{t as E,q as F,u as G}from"./DsH_B9zr.mjs";import{b as H}from"./Bwnpzbiq.mjs";import{p as i}from"./CDiwszz9.mjs";import{p as I}from"./CIfmyYqU.mjs";var J=W('<div role="toolbar"><!></div>');function Y(_,e){B(e,!1);const g=()=>N(I,"$pageTheme",v),[v,h]=S(),l=p(),u=p();let w=i(e,"id",8,void 0),y=i(e,"class",8,""),n=i(e,"size",8,void 0),m=i(e,"wrap",8,void 0),a=p();f(()=>b(n()),()=>{r(l,n()?`--buttons-size: ${n()}rem; `:"")}),f(()=>b(m()),()=>{m()===void 0?r(a,""):r(a,m()?"--buttons-wrap: wrap; ":"--buttons-wrap: nowrap; ")}),f(()=>(s(l),s(a)),()=>{r(u,s(l)+s(a))}),j(),T();var t=J();let c,d;var z=k(t);C(z,e,"default",{}),q(t),x(()=>{var o;E(t,"id",w()),c=F(t,1,`button-toolbar btn-toolbar ${(o=y())!=null?o:""}`,"svelte-1v9a56g",c,{nightMode:g().isDark}),d=G(t,s(u),d,{"--icon-align":"baseline"})}),A("focusout",t,function(o){H.call(this,e,o)}),D(_,t),M(),h()}export{Y as B};
