import{s}from"../chunks/BsocXRUK.mjs";import"../chunks/E-vkuI0X.mjs";import{i as m}from"../chunks/BY-InYMh.mjs";import{p as r,au as a,e as c,f as i,c as l,d}from"../chunks/CNnnUJHC.mjs";import{s as u}from"../chunks/Dnm-XY8D.mjs";import{m as f,t as p}from"../chunks/Dbye-yJ_.mjs";function h(){const t=window.location.hash=="#night";return t&&(document.documentElement.className="night-mode",document.documentElement.dataset.bsTheme="dark"),t}const g=!1,y=!1,_=async()=>{h(),await s()},k=Object.freeze(Object.defineProperty({__proto__:null,load:_,prerender:y,ssr:g},Symbol.toStringTag,{value:"Module"}));function x(t,e){r(e,!1),a(f,new Map),a(p,"ontouchstart"in document.documentElement),m();var o=c(),n=i(o);u(n,e,"default",{}),l(t,o),d()}export{x as component,k as universal};
