import"../chunks/E-vkuI0X.mjs";import{i as e}from"../chunks/BY-InYMh.mjs";import{p,d as i,i as m,u as n}from"../chunks/CNnnUJHC.mjs";import{p as s}from"../chunks/CDiwszz9.mjs";import{i as l}from"../chunks/Dnm-XY8D.mjs";import{I as u}from"../chunks/CunlPwQF.mjs";const c=(async({params:t})=>({path:t.path})),v=Object.freeze(Object.defineProperty({__proto__:null,load:c},Symbol.toStringTag,{value:"Module"}));function y(t,r){p(r,!1);let o=s(r,"data",8);const a={doImport:()=>l({val:o().path},{})};e(),u(t,{get path(){return m(o()),n(()=>o().path)},get importer(){return a}}),i()}export{y as component,v as universal};
