import"./E-vkuI0X.mjs";import{i as N}from"./BY-InYMh.mjs";import{h as y,r as C,b as q,c as v,e as S,f as j,j as w,p as z,d as B,g as p,s as E,m as H}from"./CNnnUJHC.mjs";import{s as x}from"./Dnm-XY8D.mjs";import{t as o,q as D}from"./DsH_B9zr.mjs";import{b as M,p as P}from"./89V6BR2_.mjs";import{p as e}from"./CDiwszz9.mjs";import{C as R}from"./BsEIMH9Z.mjs";import{c as A,o as F,e as g}from"./DhVU3Ruq.mjs";import{b as G}from"./CCslPK7N.mjs";import{b as k}from"./Bwnpzbiq.mjs";var I=w("<div><!></div>");function tt(r,t){let d=e(t,"id",8,void 0),f=e(t,"class",8,""),m=e(t,"height",12,0),b=e(t,"breakpoint",8,"fluid");var i=I(),c=y(i);R(c,{get breakpoint(){return b()},children:(s,h)=>{var n=S(),u=j(n);x(u,t,"default",{}),v(s,n)},$$slots:{default:!0}}),C(i),q(()=>{var s;o(i,"id",d()),D(i,1,`sticky-container ${(s=f())!=null?s:""}`,"svelte-123l061")}),M(i,"offsetHeight",m),v(r,i)}var J=w("<button><!></button>");function et(r,t){z(t,!1);let d=e(t,"id",8,void 0),f=e(t,"class",8,""),m=e(t,"primary",8,!1),b=e(t,"tooltip",8,void 0),i=e(t,"active",8,!1),c=e(t,"disabled",8,!1),s=e(t,"tabbable",8,!1),h=e(t,"ellipsis",8,!1),n=H();const u=A();F(()=>u("mount",{button:p(n)})),N();var a=J();let _;var L=y(a);x(L,t,"default",{}),C(a),G(a,l=>E(n,l),()=>p(n)),q(()=>{var l;o(a,"id",d()),_=D(a,1,`label-button ${(l=f())!=null?l:""}`,"svelte-qwvah",_,{active:i(),primary:m(),ellipsis:h()}),o(a,"title",b()),a.disabled=c(),o(a,"tabindex",s()?0:-1)}),g("click",a,function(l){k.call(this,t,l)}),g("mousedown",a,P(function(l){k.call(this,t,l)})),v(r,a),B()}export{et as L,tt as S};
