import{o as _,I as w,b as c}from"./Bwnpzbiq.mjs";import"./E-vkuI0X.mjs";import{i as M}from"./BY-InYMh.mjs";import{c as I,o as k,e as f}from"./DhVU3Ruq.mjs";import{p as z,h as C,e as E,f as S,c as u,r as X,b as x,d as y,j as B,g as d,s as P,m as j}from"./CNnnUJHC.mjs";import{s as q}from"./Dnm-XY8D.mjs";import{t as D,q as H}from"./DsH_B9zr.mjs";import{b as N}from"./CCslPK7N.mjs";import{p as i}from"./CDiwszz9.mjs";function V(o){throw new Error(`unreachable: ${o}`)}function W(...o){return()=>{for(const t of o)t()}}function Y(o){let t=!1;function n(s){t=s}const r=_(document,"keydown",s=>{s.key==="Escape"&&t&&(s.stopImmediatePropagation(),o&&o())},{capture:!0});return{set:n,remove:r}}var O=B('<button tabindex="-1"><!></button>');function Z(o,t){z(t,!1);let n=i(t,"class",8,""),r=i(t,"tooltip",8,void 0),s=i(t,"iconSize",8,100),p=i(t,"widthMultiplier",8,1),h=i(t,"flipX",8,!1);const b=I();let l=j();k(()=>{b("mount",{span:d(l)})}),M();var a=O(),g=C(a);w(g,{get iconSize(){return s()},get widthMultiplier(){return p()},get flipX(){return h()},children:(e,R)=>{var m=E(),v=S(m);q(v,t,"default",{}),u(e,m)},$$slots:{default:!0}}),X(a),N(a,e=>P(l,e),()=>d(l)),x(()=>{var e;D(a,"title",r()),H(a,1,`badge ${(e=n())!=null?e:""}`,"svelte-1fmrmgo")}),f("click",a,function(e){c.call(this,t,e)}),f("mouseenter",a,function(e){c.call(this,t,e)}),f("mouseleave",a,function(e){c.call(this,t,e)}),u(o,a),y()}export{Z as B,V as a,Y as r,W as s};
