import"./E-vkuI0X.mjs";import"./BY-InYMh.mjs";import{h as i,r as p,b as x,c as d,j as f}from"./CNnnUJHC.mjs";import{s as v}from"./Dnm-XY8D.mjs";import{q as n}from"./DsH_B9zr.mjs";import{p as e}from"./CDiwszz9.mjs";var b=f("<div><!></div>");function j(r,s){let m=e(s,"class",8,""),l=e(s,"breakpoint",8,"xs");var o=b();let t;var c=i(o);v(c,s,"default",{}),p(o),x(()=>{var a;return t=n(o,1,`col ${(a=m())!=null?a:""}`,"svelte-c0c30t",t,{"col-xs":l()==="xs","col-sm":l()==="sm","col-md":l()==="md","col-lg":l()==="lg","col-xl":l()==="xl","col-xxl":l()==="xxl"})}),d(r,o)}export{j as C};
